pyiron_gui
============
.. image:: https://coveralls.io/repos/github/pyiron/pyiron_gui/badge.svg?branch=master
    :target: https://coveralls.io/github/pyiron/pyiron_gui?branch=master
    :alt: Coverage Status

.. image:: https://anaconda.org/conda-forge/pyiron_gui/badges/latest_release_date.svg
    :target: https://anaconda.org/conda-forge/pyiron_gui/
    :alt: Release_Date

.. image:: https://github.com/pyiron/pyiron_gui/workflows/Python%20package/badge.svg
    :target: https://github.com/pyiron//pyiron_gui/actions
    :alt: Build Status

    
This repository is for GUI extensions to the overall pyiron framework.

Getting started:
----------------
Test pyiron with mybinder:

.. image:: https://mybinder.org/badge_logo.svg
     :target: https://mybinder.org/v2/gh/pyiron/pyiron_gui/master
     :alt: mybinder
